AlterColumn class

Implemented types

Constructors

AlterColumn({required Ident columnName, required AlterColumnOperation op})
const
AlterColumn.fromJson(Object? json_)
Returns a new instance from a JSON value. May throw if the value does not have the expected structure.
factory

Properties

columnName Ident
final
hashCode int
The hash code for this object.
no setteroverride
op AlterColumnOperation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Ident? columnName, AlterColumnOperation? op}) AlterColumn
Returns a new instance by overriding the values passed as arguments
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Returns a JSON representation of this.
override
toString() String
A string representation of this object.
override
toWasm() List<Object?>
Returns this as a WASM canonical abi value.
override

Operators

operator ==(Object other) bool
The equality operator.
override